package com.ruoyi.member.controller;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.member.domain.MemberApply;
import com.ruoyi.member.service.IMemberApplyService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 通告主认证申请Controller
 * 
 * @author pqz
 * @date 2025-03-17
 */
@RestController
@RequestMapping("/member/apply")
public class MemberApplyController extends BaseController
{
    @Autowired
    private IMemberApplyService memberApplyService;

    /**
     * 查询通告主认证申请列表
     */
    @PreAuthorize("@ss.hasPermi('member:apply:list')")
    @GetMapping("/list")
    public AjaxResult list(MemberApply memberApply)
    {

        List<MemberApply> list = memberApplyService.list();
        return success(list);
    }

    /**
     * 导出通告主认证申请列表
     */
    @PreAuthorize("@ss.hasPermi('member:apply:export')")
    @Log(title = "通告主认证申请", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MemberApply memberApply)
    {
        List<MemberApply> list = memberApplyService.list();
        ExcelUtil<MemberApply> util = new ExcelUtil<MemberApply>(MemberApply.class);
        util.exportExcel(response, list, "通告主认证申请数据");
    }

    /**
     * 获取通告主认证申请详细信息
     */
    @PreAuthorize("@ss.hasPermi('member:apply:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id)
    {
        return success(memberApplyService.getById(id));
    }

    /**
     * 新增通告主认证申请
     */
    @PreAuthorize("@ss.hasPermi('member:apply:add')")
    @Log(title = "通告主认证申请", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MemberApply memberApply)
    {
        return toAjax(memberApplyService.save(memberApply));
    }

    /**
     * 修改通告主认证申请
     */
    @PreAuthorize("@ss.hasPermi('member:apply:edit')")
    @Log(title = "通告主认证申请", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MemberApply memberApply)
    {
        return toAjax(memberApplyService.updateById(memberApply));
    }

    /**
     * 删除通告主认证申请
     */
    @PreAuthorize("@ss.hasPermi('member:apply:remove')")
    @Log(title = "通告主认证申请", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids)
    {
        List<String> list = new ArrayList<>(Arrays.asList(ids));
        return toAjax(memberApplyService.removeBatchByIds(list));
    }
}
